<?php
/**
* @author Amasty Team
* @copyright Copyright (c) 2022 Amasty (https://www.amasty.com)
* @package ILN Compatibility with Live Search for Magento 2 (System)
*/

declare(strict_types=1);

namespace Amasty\ShopByLiveSearch\Plugin\LiveSearchAdapter\Model\QueryArgumentProcessor\FilterHandler;

use Amasty\Shopby\Model\Search\RequestGenerator as ShopbyRequestGenerator;
use Magento\LiveSearchAdapter\Model\QueryArgumentProcessor\FilterHandler\FilterHandlerFactory;
use Magento\LiveSearchAdapter\Model\QueryArgumentProcessor\FilterHandler\FilterHandlerInterface;

class ResolveAndLogic
{
    /**
     * If filter use AND logic , we need split filter by attribute.
     * Example: need {"attribute":color, "in":["Black"], "attribute":color, "in":["Blue"]} instead of
     * {"attribute":color, "in":["Black", "Blue"]}
     *
     * @param FilterHandlerFactory $filterHandlerFactory
     * @param callable $proceed
     * @param string $filterKey
     * @param array|string $filterValue
     *
     * @see FilterHandlerFactory::resolve
     * @see \Amasty\Shopby\Model\Layer\Filter\Attribute::getFakeAttributeCodeForApply
     *
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function aroundResolve(
        FilterHandlerFactory $filterHandlerFactory,
        callable $proceed,
        string $filterKey,
        $filterValue
    ): FilterHandlerInterface {
        $regexp = sprintf('@%s[0-9]+@', ShopbyRequestGenerator::FAKE_SUFFIX);
        $filterKey = preg_replace($regexp, '', $filterKey);

        return $proceed($filterKey, $filterValue);
    }
}
